import { fetch } from '@/api/index'
import { getToken, removeToken, removeLocale } from '@/utils/auth'
import { resetRouter } from '@/router'

const getDefaultState = () => {
  return {
    token: getToken(),
    name: '',
    avatar: '',
    locale: '',
    roleName: ''
  }
}

const state = getDefaultState()

const getters = {
  isOnLineOperation(state) {
    return /^线上运营/.test(state.roleName)
  }
}

const mutations = {
  RESET_STATE: (state) => {
    Object.assign(state, getDefaultState())
  },
  SET_TOKEN: (state, token) => {
    state.token = token
  },
  SET_NAME: (state, name) => {
    state.name = name
  },
  SET_AVATAR: (state, avatar) => {
    state.avatar = avatar
  },
  SET_LOCALE(state, value) {
    state.locale = value
  },
  SET_ROLE_NAME(state, value) {
    state.roleName = value
  }
}

const actions = {
  // get user info
  getInfo({ commit, state }) {
    return new Promise(async (resolve, reject) => {
      const data = await fetch('/api/auth/userGetInfo', { token: getToken() }, 'get')
      // const data = {code: 0, data: {username: 'admin'}}
      if (data.code === 200) {
        const { user_name, role_name } = data.data
        commit('SET_NAME', user_name)
        commit('SET_AVATAR', 'avatar')
        commit('SET_ROLE_NAME', role_name)

        resolve(data.data)
      } else {
        reject('error')
      }
    })
  },

  // user logout
  logout({ commit, state, dispatch }) {
    return new Promise((resolve, reject) => {
      removeToken() // must remove  token  first
      removeLocale()
      resetRouter()
      commit('RESET_STATE')
      dispatch('tagsView/delAllViews', null, { root: true })

      resolve()
    })
  },

  // remove token
  resetToken({ commit }) {
    return new Promise(resolve => {
      removeToken() // must remove  token  first
      removeLocale()
      commit('RESET_STATE')
      resolve()
    })
  }
}

export default {
  namespaced: true,
  state,
  getters,
  mutations,
  actions
}

